Real-life usage
~~~~~~~~~~~~~~~

Below are some examples of applications using `argh`, grouped by supported
version of Python.

Python 3:

    * Aurifere_

Python 2 and 3:

    * Watchdog_

Python 2:

    * Tool_
    * Poni_
    * Pyg_
    * Barman_
    * Timetra_

...and more.  Well, there's probably no need to keep a complete
and up-to-date list.  Still, please let me know anyway if you use `argh`
in your project.  I'll be glad to know. :-)

.. _Tool: http://pypi.python.org/pypi/tool
.. _Watchdog: https://github.com/gorakhargosh/watchdog/
.. _Poni: https://github.com/melor/poni/commit/14e8ccbb50e9e17b95a2f2a0d2cd0af5d90ca22b
.. _Pyg: https://github.com/rubik/pyg/commit/a201de1d70536e7e4637a6079f03174b7b493ffa
.. _Barman: http://pgbarman.org
.. _Aurifere: https://github.com/madjar/aurifere
.. _Timetra: https://bitbucket.org/timetra/timetra
